(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     33334,        808]
NotebookOptionsPosition[     31915,        757]
NotebookOutlinePosition[     32280,        773]
CellTagsIndexPosition[     32237,        770]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Functions and algorithms", "Section",
 CellChangeTimes->{{3.591633768661296*^9, 3.591633785134925*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bases", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<a\>\"", ",", "\"\<c\>\"", ",", "\"\<g\>\"", ",", "\"\<t\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591624456042656*^9, 3.5916244932019215`*^9}, {
  3.5916323430351915`*^9, 3.5916323482456007`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IToB", "[", "basesAsInts_", "]"}], ":=", 
   RowBox[{"StringJoin", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
       "bases", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], "&"}],
       ",", "basesAsInts"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916243532072754`*^9, 3.5916244043129654`*^9}, {
   3.5916244369638224`*^9, 3.5916244466826396`*^9}, {3.591624518115165*^9, 
   3.591624523715575*^9}, {3.5916248544670653`*^9, 3.5916248581672773`*^9}, 
   3.591626215272108*^9, {3.591626477761815*^9, 3.5916264925038404`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BToI", "[", "intAsBases_", "]"}], ":=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"#", "==", "\"\<a\>\""}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"#", "\[Equal]", "\"\<c\>\""}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", 
            RowBox[{"#", "\[Equal]", "\"\<g\>\""}]}], "}"}]}], "}"}], ",", 
        "4"}], "]"}], "&"}], ",", 
     RowBox[{"Characters", "[", "intAsBases", "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.591626456140177*^9, 3.5916265953236217`*^9}, {
  3.5916266554773273`*^9, 3.5916266909049892`*^9}, {3.591632383423663*^9, 
  3.5916323879944706`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FakeData", "[", 
    RowBox[{"t_", ",", "n_", ",", "motif_", ",", "mutationProbability_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "DNA", ",", "l", ",", "s", ",", "i", ",", "sequenceAsInts", ",", 
       "motifAsInts", ",", "mutatedMotifAsInts"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"l", "=", 
       RowBox[{"StringLength", "[", "motif", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"motifAsInts", "=", 
       RowBox[{"BToI", "[", "motif", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DNA", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"IToB", "[", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "4"}], "}"}], ",", "n"}], "]"}], "]"}], ",", 
         RowBox[{"{", "t", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s", "=", 
       RowBox[{"RandomInteger", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"n", "-", "l", "+", "1"}]}], "}"}], ",", "t"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "\[LessEqual]", "t"}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"sequenceAsInts", "=", 
          RowBox[{"BToI", "[", 
           RowBox[{
           "DNA", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutatedMotifAsInts", "=", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Random", "[", "]"}], ">", "mutationProbability"}], 
               ",", "#", ",", 
               RowBox[{"RandomInteger", "[", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "4"}], "}"}], "]"}]}], "]"}], "&"}], ",", 
            "motifAsInts"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sequenceAsInts", "\[LeftDoubleBracket]", 
           RowBox[{"Range", "[", 
            RowBox[{
             RowBox[{
             "s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
             RowBox[{
              RowBox[{
              "s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "+", "l", "-", "1"}]}], "]"}], "\[RightDoubleBracket]"}], "=", 
          "mutatedMotifAsInts"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
          "DNA", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "=", 
          RowBox[{"IToB", "[", "sequenceAsInts", "]"}]}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"DNA", ",", "s"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.591625876329313*^9, 3.591625972815482*^9}, {
   3.5916261034043117`*^9, 3.591626298529454*^9}, {3.591626416672616*^9, 
   3.5916264401349573`*^9}, {3.591626731511861*^9, 3.5916267709029303`*^9}, {
   3.5916268272190285`*^9, 3.5916270112993517`*^9}, {3.591627057444233*^9, 
   3.5916270623270416`*^9}, {3.5916271844440565`*^9, 3.591627205192093*^9}, {
   3.5916272529905767`*^9, 3.59162725498738*^9}, 3.591627486365261*^9, {
   3.5916275383767524`*^9, 3.591627572837213*^9}, {3.5916276170476904`*^9, 
   3.591627674627392*^9}, {3.5916278601273174`*^9, 3.591627860330118*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NextVertex", "[", 
    RowBox[{"a_", ",", "i_", ",", "L_", ",", "k_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a2", ",", "i2", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a2", "=", "a"}], ";", "\[IndentingNewLine]", 
      RowBox[{"i2", "=", "i"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "<", "L"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"a2", "\[LeftDoubleBracket]", 
           RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], "=", "1"}], 
         ";", 
         RowBox[{"Return", "[", 
          RowBox[{"Append", "[", 
           RowBox[{"a2", ",", 
            RowBox[{"i2", "+", "1"}]}], "]"}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"j", "=", "L"}], ",", 
        RowBox[{"j", "\[GreaterEqual]", "1"}], ",", 
        RowBox[{"j", "--"}], ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "<", 
           "k"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
            "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             RowBox[{
             "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
             "+", "1"}]}], ";", 
           RowBox[{"Return", "[", 
            RowBox[{"Append", "[", 
             RowBox[{"a2", ",", "j"}], "]"}], "]"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Append", "[", 
       RowBox[{"a2", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.591628005145172*^9, 3.5916280503228517`*^9}, {
   3.591628098792137*^9, 3.5916283008758917`*^9}, {3.591628364758004*^9, 
   3.5916283649608045`*^9}, 3.5916320202238245`*^9, {3.6074065127175303`*^9, 
   3.607406548410393*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ByPass", "[", 
    RowBox[{"a_", ",", "i_", ",", "L_", ",", "k_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a2", ",", "i2", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a2", "=", "a"}], ";", "\[IndentingNewLine]", 
      RowBox[{"i2", "=", "i"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"j", "=", "i"}], ",", 
        RowBox[{"j", "\[GreaterEqual]", "1"}], ",", 
        RowBox[{"j", "--"}], ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "<", 
           "k"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
            "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             RowBox[{
             "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
             "+", "1"}]}], ";", 
           RowBox[{"Return", "[", 
            RowBox[{"Append", "[", 
             RowBox[{"a2", ",", "j"}], "]"}], "]"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Append", "[", 
       RowBox[{"a2", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.591628391683651*^9, 3.591628421635704*^9}, {
   3.59162846497258*^9, 3.5916284840358133`*^9}, {3.5916285199938765`*^9, 
   3.591628534517502*^9}, 3.5916320178058205`*^9, {3.6074065598920135`*^9, 
   3.60740657524244*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NextVertexC", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "_Integer", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a2", ",", "i2", ",", "j"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"a2", "=", "a"}], ";", "\[IndentingNewLine]", 
        RowBox[{"i2", "=", "i"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "<", "L"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"a2", "\[LeftDoubleBracket]", 
             RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], "=", "1"}], 
           ";", 
           RowBox[{"Return", "[", 
            RowBox[{"Append", "[", 
             RowBox[{"a2", ",", 
              RowBox[{"i2", "+", "1"}]}], "]"}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"j", "=", "L"}], ",", 
          RowBox[{"j", "\[GreaterEqual]", "1"}], ",", 
          RowBox[{"j", "--"}], ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
             "<", "k"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
              "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
              "=", 
              RowBox[{
               RowBox[{
               "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", "1"}]}], ";", 
             RowBox[{"Return", "[", 
              RowBox[{"Append", "[", 
               RowBox[{"a2", ",", "j"}], "]"}], "]"}]}]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Append", "[", 
         RowBox[{"a2", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916329736360993`*^9, 3.591632994009735*^9}, {
   3.591633044288624*^9, 3.591633071822672*^9}, {3.5916864261613154`*^9, 
   3.591686427674518*^9}, {3.6037311406945457`*^9, 3.6037311485101595`*^9}, {
   3.603731269732771*^9, 3.6037312990452223`*^9}, 3.607407270226261*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ByPassC", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "_Integer", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a2", ",", "i2", ",", "j"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"a2", "=", "a"}], ";", "\[IndentingNewLine]", 
        RowBox[{"i2", "=", "i"}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"j", "=", "i"}], ",", 
          RowBox[{"j", "\[GreaterEqual]", "1"}], ",", 
          RowBox[{"j", "--"}], ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
             "<", "k"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
              "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
              "=", 
              RowBox[{
               RowBox[{
               "a2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", "1"}]}], ";", 
             RowBox[{"Return", "[", 
              RowBox[{"Append", "[", 
               RowBox[{"a2", ",", "j"}], "]"}], "]"}]}]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Append", "[", 
         RowBox[{"a2", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591633085457096*^9, 3.5916331252995653`*^9}, {
   3.5916864118560905`*^9, 3.5916864152412963`*^9}, {3.6037311276529226`*^9, 
   3.6037311326449313`*^9}, {3.6037312274150977`*^9, 
   3.6037312640487614`*^9}, {3.60740676284837*^9, 3.6074067631291704`*^9}, 
   3.607407278509876*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Example - Median String Search", "Section",
 CellChangeTimes->{{3.5916338228089905`*^9, 3.5916338438222275`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"l", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "32"}], ";"}]}], "Input",
 CellChangeTimes->{{3.591624274255537*^9, 3.5916242756751394`*^9}, {
   3.5916278165720415`*^9, 3.5916278470388947`*^9}, {3.5916301004346523`*^9, 
   3.5916301262838984`*^9}, {3.5916318095912547`*^9, 
   3.5916318155660653`*^9}, {3.591632046775071*^9, 3.591632047087072*^9}, {
   3.5916321223728037`*^9, 3.5916321236988063`*^9}, {3.5916325451023464`*^9, 
   3.5916325487059526`*^9}, 3.591632599594242*^9, {3.591632736858884*^9, 
   3.5916327374672847`*^9}, {3.5916335566569233`*^9, 3.591633562350933*^9}, {
   3.5916336125050216`*^9, 3.5916336132070227`*^9}, {3.5916337141548*^9, 
   3.591633714513601*^9}, {3.591635798735385*^9, 3.5916358001081877`*^9}, {
   3.5916362391407585`*^9, 3.59163623946836*^9}, {3.5916715289496307`*^9, 
   3.591671529261631*^9}, {3.5916858963375845`*^9, 3.591685897632387*^9}, {
   3.591686121009179*^9, 3.5916861214771805`*^9}, {3.591686897350487*^9, 
   3.5916868979276886`*^9}, {3.592209389778014*^9, 3.5922093964473963`*^9}, {
   3.5922095760106664`*^9, 3.592209576321684*^9}, {3.603730220402129*^9, 
   3.6037302226953335`*^9}, {3.6037305657555356`*^9, 
   3.6037305802791615`*^9}, {3.6037306538956904`*^9, 
   3.6037306580140977`*^9}, {3.6037307569182715`*^9, 3.603730771473097*^9}, {
   3.6037309027317276`*^9, 3.6037309077393365`*^9}, {3.603732281401348*^9, 
   3.603732285488555*^9}, {3.60373232247622*^9, 3.6037323295430326`*^9}, {
   3.6037323723339076`*^9, 3.6037323819435244`*^9}, {3.603732450583645*^9, 
   3.6037324536724505`*^9}, {3.6037324946693225`*^9, 3.603732495433724*^9}, {
   3.6037330159080844`*^9, 3.603733016251285*^9}, {3.603733059712961*^9, 
   3.6037330599625616`*^9}, {3.6037746063671613`*^9, 
   3.6037746234959917`*^9}, {3.6074068108964543`*^9, 3.607406817432866*^9}, {
   3.60740711012158*^9, 3.6074071127735844`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"motifAsInts", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", "l"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"motif", "=", 
  RowBox[{"IToB", "[", "motifAsInts", "]"}]}]}], "Input",
 CellChangeTimes->{{3.5916242789979453`*^9, 3.5916243402592525`*^9}, 
   3.5916245289727845`*^9, {3.591624866053728*^9, 3.5916248794404936`*^9}, {
   3.591625841042051*^9, 3.5916258485768642`*^9}, {3.5916301404799232`*^9, 
   3.591630140620323*^9}}],

Cell[BoxData["\<\"attgtatc\"\>"], "Output",
 CellChangeTimes->{
  3.591624880127533*^9, 3.591625852570471*^9, 3.5916262190317144`*^9, 
   3.5916266012048316`*^9, 3.5916278501589003`*^9, {3.591630127999901*^9, 
   3.591630141088324*^9}, 3.5916310721457596`*^9, 3.591631190550967*^9, {
   3.591631817219668*^9, 3.591631821072875*^9}, 3.591631990770973*^9, {
   3.5916320495050764`*^9, 3.591632056369088*^9}, 3.59163212583601*^9, 
   3.5916322828346863`*^9, {3.591632360398022*^9, 3.591632367823635*^9}, 
   3.5916323979316883`*^9, 3.5916325502347555`*^9, 3.5916326015286455`*^9, 
   3.591632738855687*^9, {3.591633564924938*^9, 3.591633578091361*^9}, 
   3.591633614486225*^9, 3.591633716229604*^9, 3.591634835323493*^9, 
   3.5916350902747407`*^9, 3.5916356718915625`*^9, 3.59163580129379*^9, 
   3.591635837127053*^9, 3.5916359075611763`*^9, 3.5916359771372986`*^9, 
   3.5916360482266235`*^9, 3.5916714196246386`*^9, 3.5916716654030704`*^9, 
   3.5916855763118224`*^9, 3.5916856123166857`*^9, 3.591685904636799*^9, 
   3.591686001294569*^9, 3.5916861238171844`*^9, 3.5916866939607325`*^9, 
   3.591686899628091*^9, 3.5916880401864166`*^9, {3.591688262796728*^9, 
   3.5916882709467397`*^9}, {3.5916884671570144`*^9, 3.591688474047024*^9}, {
   3.591689053419835*^9, 3.591689061039846*^9}, 3.592209402923766*^9, 
   3.592209577869773*^9, 3.595183162350221*^9, {3.6037302271725407`*^9, 
   3.603730234660554*^9}, 3.603730581417963*^9, 3.603730659761301*^9, {
   3.6037307596950765`*^9, 3.603730772580699*^9}, 3.6037309089093385`*^9, 
   3.6037310382335653`*^9, 3.6037317192631607`*^9, 3.6037318831950483`*^9, 
   3.6037320842482014`*^9, {3.6037322641321173`*^9, 3.6037322898253627`*^9}, 
   3.6037323309782352`*^9, {3.603732377887518*^9, 3.6037323829263268`*^9}, 
   3.6037324553572536`*^9, 3.603732496619326*^9, 3.603732955442378*^9, {
   3.603732991821642*^9, 3.603733017499287*^9}, {3.6037330661557727`*^9, 
   3.603733075562589*^9}, 3.6037331229242725`*^9, {3.603774230281701*^9, 
   3.603774249703735*^9}, 3.6037746400632205`*^9, 3.603774724568569*^9, 
   3.607406821332873*^9, 3.6074071143179874`*^9, 3.607407334030373*^9, 
   3.607407379395253*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"DNA", ",", "s"}], "}"}], "=", 
   RowBox[{"FakeData", "[", 
    RowBox[{"t", ",", "n", ",", "motif", ",", "0.25"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.591626241402154*^9, 3.5916262519009724`*^9}, {
   3.5916270368209968`*^9, 3.591627068957053*^9}, {3.5916271001883082`*^9, 
   3.591627122371547*^9}, {3.591627507332698*^9, 3.591627507457498*^9}, {
   3.5916277315674915`*^9, 3.5916277325970936`*^9}, 3.5916277804891777`*^9, {
   3.591627854214907*^9, 3.591627866819729*^9}, {3.5916319857945642`*^9, 
   3.5916319858881645`*^9}, {3.5916321694536867`*^9, 
   3.5916321699372873`*^9}, {3.591632370148039*^9, 3.591632371474042*^9}, 
   3.5916336375430655`*^9, 3.5916337085075903`*^9, 3.591686143130018*^9, 
   3.5916875085736723`*^9, 3.5916880349654093`*^9, {3.603774262261757*^9, 
   3.6037742630417585`*^9}, {3.6037747329769835`*^9, 
   3.6037747373293915`*^9}, {3.607406826512082*^9, 3.607406826777282*^9}, {
   3.6074071166267915`*^9, 3.607407117110392*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "DNA", "]"}]], "Input",
 CellChangeTimes->{{3.591627125241952*^9, 3.5916271294383593`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\<\"cttacttgtatctctcacctgtgtattctcgc\"\>"},
      {"\<\"aatagaccagcgcttcttaactcgcctgagat\"\>"},
      {"\<\"ttattgtagccaactggaaaccgtaccagtcc\"\>"},
      {"\<\"gggccgccattgggaagtactattgtgaatag\"\>"},
      {"\<\"cgctggtaaagtagatggtatcttcctgagtc\"\>"},
      {"\<\"gccagacactagttatgggattgtatcgtggc\"\>"},
      {"\<\"tccatgccatcgatgattgtatctaaccgcgc\"\>"},
      {"\<\"gctaatctctaaatcgtaggaccattccttta\"\>"},
      {"\<\"tgatgtcgattgtctcaccctgtaggccctgt\"\>"},
      {"\<\"ttcatcgtatcgtcagttctgccagcgggcat\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.59162712975036*^9, {3.5916276791826*^9, 3.5916276852354107`*^9}, 
   3.5916277358886995`*^9, 3.5916278686917324`*^9, 3.591630144052329*^9, 
   3.591631075920966*^9, 3.591631190597768*^9, 3.59163182369368*^9, 
   3.591631993064177*^9, 3.5916320593330936`*^9, 3.591632133448824*^9, 
   3.591632173494094*^9, 3.5916322856114907`*^9, {3.591632373018444*^9, 
   3.59163239930449*^9}, 3.5916325535263615`*^9, 3.591632604555051*^9, 
   3.5916327430364943`*^9, {3.5916335664225407`*^9, 3.591633582131768*^9}, {
   3.591633616264628*^9, 3.5916336392122684`*^9}, 3.5916337175868063`*^9, 
   3.5916348380534983`*^9, 3.591635093566347*^9, 3.5916352905946927`*^9, 
   3.591635673311165*^9, 3.591635803072193*^9, 3.5916358390614557`*^9, 
   3.5916359103535814`*^9, 3.5916359808501053`*^9, 3.591636050379427*^9, 
   3.5916362447099686`*^9, 3.591671419687039*^9, 3.591671628243805*^9, 
   3.5916716654342704`*^9, 3.5916855766706233`*^9, 3.591685612332286*^9, 
   3.5916859063840027`*^9, 3.5916860031821723`*^9, {3.5916861258139877`*^9, 
   3.5916861448148212`*^9}, 3.5916866961407356`*^9, 3.591686901297294*^9, 
   3.5916875100436745`*^9, 3.591688044006422*^9, 3.5916882736867437`*^9, 
   3.5916884783070297`*^9, 3.591689088929885*^9, 3.5922094087551003`*^9, 
   3.59220958027291*^9, 3.595183165049026*^9, 3.6037302411501656`*^9, 
   3.603730582868766*^9, 3.6037306621169047`*^9, {3.603730761099079*^9, 
   3.6037307741251016`*^9}, 3.603730910235341*^9, 3.603731040339569*^9, 
   3.603731720682763*^9, 3.6037318843026505`*^9, 3.603732085605404*^9, {
   3.6037322656297207`*^9, 3.6037322912449656`*^9}, 3.6037323323042374`*^9, {
   3.6037323791511197`*^9, 3.603732384267929*^9}, 3.6037324568548565`*^9, 
   3.603732498553729*^9, 3.603732956908781*^9, {3.6037329973440514`*^9, 
   3.6037330221792955`*^9}, {3.6037330661869726`*^9, 3.6037330756093893`*^9}, 
   3.6037331271830797`*^9, {3.603774252152939*^9, 3.603774264523761*^9}, 
   3.603774648783636*^9, 3.6037747466270075`*^9, 3.607406828976886*^9, 
   3.6074071182023945`*^9, 3.607407338226781*^9, 3.607407379395253*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DNA2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"StringTake", "[", 
       RowBox[{
        RowBox[{"DNA", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{
           RowBox[{
           "s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "-", 
           "1"}]}], "}"}]}], "]"}], "<>", 
      RowBox[{"ToUpperCase", "[", 
       RowBox[{"StringTake", "[", 
        RowBox[{
         RowBox[{
         "DNA", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "+", 
            "l", "-", "1"}]}], "}"}]}], "]"}], "]"}], "<>", 
      RowBox[{"StringTake", "[", 
       RowBox[{
        RowBox[{"DNA", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
           "s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "+", 
           "l"}], ",", "n"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "t"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916352404250045`*^9, 3.5916353693904314`*^9}, {
  3.591635440167755*^9, 3.5916354961250534`*^9}, {3.5916355552033577`*^9, 
  3.5916356196938705`*^9}, {3.5916358776091237`*^9, 3.5916358780147247`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "DNA2", "]"}]], "Input",
 CellChangeTimes->{{3.59163563086349*^9, 3.5916356357930994`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\<\"cttaCTTGTATCtctcacctgtgtattctcgc\"\>"},
      {"\<\"AATAGACCagcgcttcttaactcgcctgagat\"\>"},
      {"\<\"ttATTGTAGCcaactggaaaccgtaccagtcc\"\>"},
      {"\<\"gggccgccattgggaagtactATTGTGAAtag\"\>"},
      {"\<\"cgctggtaaagtagATGGTATCttcctgagtc\"\>"},
      {"\<\"gccagacactagttatgggATTGTATCgtggc\"\>"},
      {"\<\"tccatgccatcgatgATTGTATCtaaccgcgc\"\>"},
      {"\<\"gctaatctctaaATCGTAGGaccattccttta\"\>"},
      {"\<\"tgatgtcgATTGTCTCaccctgtaggccctgt\"\>"},
      {"\<\"ttcATCGTATCgtcagttctgccagcgggcat\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.5916356360738993`*^9, {3.5916356764311705`*^9, 3.5916356831859827`*^9}, 
   3.591635805396597*^9, 3.5916358412298603`*^9, 3.591635880011528*^9, 
   3.5916359132395864`*^9, 3.5916359827221084`*^9, 3.591636053468233*^9, 
   3.591636149424001*^9, 3.591636246503972*^9, 3.5916714197026386`*^9, {
   3.5916716654654703`*^9, 3.5916716761670895`*^9}, 3.5916855767174234`*^9, 
   3.591685612363486*^9, 3.5916859090204067`*^9, 3.5916860060213776`*^9, {
   3.591686131539198*^9, 3.591686146562024*^9}, 3.5916866995407405`*^9, 
   3.591686903060097*^9, 3.5916875118936768`*^9, 3.5916880481164274`*^9, 
   3.5916882760267467`*^9, 3.5916884801470327`*^9, 3.5916890904598875`*^9, 
   3.5922094303463345`*^9, 3.5922095836671047`*^9, 3.595183183784659*^9, 
   3.603730265283408*^9, 3.603730584553569*^9, 3.603730664207309*^9, 
   3.6037307854195213`*^9, 3.6037309133397465`*^9, 3.6037310422115726`*^9, 
   3.6037317235131683`*^9, 3.6037318856286526`*^9, 3.603732087274607*^9, {
   3.6037322670805225`*^9, 3.6037322927893677`*^9}, 3.6037323438014574`*^9, 
   3.603732388417536*^9, 3.60373245913246*^9, 3.6037325014241343`*^9, 
   3.603732959170785*^9, {3.603732999138055*^9, 3.603733023910898*^9}, {
   3.603733066202573*^9, 3.603733075656189*^9}, 3.6037331320658884`*^9, {
   3.603774266723365*^9, 3.603774291699009*^9}, 3.6037746509520397`*^9, 
   3.603774748561411*^9, 3.6074068327052927`*^9, 3.607406876182569*^9, 
   3.6074071200899973`*^9, 3.6074073421891875`*^9, 3.607407379410853*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["s"], "Input",
 CellChangeTimes->{3.5916717024531355`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "1", ",", "3", ",", "22", ",", "15", ",", "20", ",", "16", ",", 
   "13", ",", "9", ",", "4"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5916717042627387`*^9, 3.591685576748623*^9, 3.591685612379086*^9, 
   3.5916859167736206`*^9, 3.59168600753458*^9, {3.5916861330212*^9, 
   3.591686147669626*^9}, 3.591686702930745*^9, 3.5916869064765034`*^9, 
   3.5916875130536785`*^9, 3.59168804972643*^9, 3.591688280456753*^9, 
   3.5916884813070345`*^9, 3.5916890912998886`*^9, 3.5922094405149164`*^9, 
   3.592209585917233*^9, 3.595183187403865*^9, 3.6037302926302557`*^9, 
   3.6037305862227716`*^9, 3.603730666001312*^9, 3.6037307862151227`*^9, 
   3.6037309143069477`*^9, 3.603731043428375*^9, 3.6037317247923703`*^9, 
   3.603731886642655*^9, 3.6037320883042088`*^9, {3.6037322680477247`*^9, 
   3.603732294271371*^9}, 3.6037323449246597`*^9, 3.6037323897903385`*^9, 
   3.6037324605988626`*^9, 3.6037325021729355`*^9, 3.6037329608711877`*^9, {
   3.6037330002144566`*^9, 3.6037330249405003`*^9}, {3.603733066218173*^9, 
   3.603733075671789*^9}, 3.6037331350766935`*^9, 3.6037747799798665`*^9, 
   3.607406878491373*^9, 3.6074071215875998`*^9, 3.6074073438739905`*^9, 
   3.607407379410853*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"alignmentMatrix", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"StringTake", "[", 
      RowBox[{
       RowBox[{"DNA2", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{
          RowBox[{"s", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
           "+", "l", "-", "1"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "t"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916324242645345`*^9, 3.5916324617514*^9}, {
   3.5916327608517256`*^9, 3.591632775656152*^9}, 3.5916358662679043`*^9, {
   3.5916880512864323`*^9, 3.5916880536464357`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "alignmentMatrix", "]"}]], "Input",
 CellChangeTimes->{{3.5916324625782013`*^9, 3.59163246718021*^9}, {
  3.5916327678093376`*^9, 3.5916327784641566`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\<\"CTTGTATC\"\>"},
      {"\<\"AATAGACC\"\>"},
      {"\<\"ATTGTAGC\"\>"},
      {"\<\"ATTGTGAA\"\>"},
      {"\<\"ATGGTATC\"\>"},
      {"\<\"ATTGTATC\"\>"},
      {"\<\"ATTGTATC\"\>"},
      {"\<\"ATCGTAGG\"\>"},
      {"\<\"ATTGTCTC\"\>"},
      {"\<\"ATCGTATC\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6037748828932467`*^9, 3.607406880597377*^9, 
  3.6074071238496037`*^9, 3.607407345418393*^9, 3.607407379426453*^9}]
}, Open  ]]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1301, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 109, 1, 71, "Section"],
Cell[691, 25, 303, 8, 31, "Input"],
Cell[997, 35, 628, 14, 31, "Input"],
Cell[1628, 51, 884, 25, 31, "Input"],
Cell[2515, 78, 3634, 85, 272, "Input"],
Cell[6152, 165, 2112, 54, 192, "Input"],
Cell[8267, 221, 1649, 41, 172, "Input"],
Cell[9919, 264, 2646, 67, 232, "Input"],
Cell[12568, 333, 2170, 55, 212, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[14775, 393, 119, 1, 41, "Section"],
Cell[14897, 396, 1988, 31, 72, "Input"],
Cell[CellGroupData[{
Cell[16910, 431, 546, 13, 52, "Input"],
Cell[17459, 446, 2154, 30, 70, "Output"]
}, Open  ]],
Cell[19628, 479, 1039, 19, 31, "Input"],
Cell[CellGroupData[{
Cell[20692, 502, 133, 2, 31, "Input"],
Cell[20828, 506, 3202, 56, 70, "Output"]
}, Open  ]],
Cell[24045, 565, 1632, 43, 31, "Input"],
Cell[CellGroupData[{
Cell[25702, 612, 133, 2, 31, "Input"],
Cell[25838, 616, 2621, 48, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28496, 669, 71, 1, 31, "Input"],
Cell[28570, 672, 1244, 20, 70, "Output"]
}, Open  ]],
Cell[29829, 695, 815, 20, 31, "Input"],
Cell[CellGroupData[{
Cell[30669, 719, 197, 3, 31, "Input"],
Cell[30869, 724, 1018, 29, 70, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
